Change Log
==========

v2019.5 (2019-11-15)
---------------------
- Bug reported (thanks Lauren Marshall) - `_FillValues` not recognised on import. Fixed by using `numpy.ma.row_stack` instead of `numpy.row_stack`.

v2019.4 (2019-08-23)
-------------------
- no changes listed prior to publication
